@@ -7,7 +7,7 @@ from solders.transaction_status import (
 from solana.rpc.core import RPCException
 from solders.rpc.errors import SendTransactionPreflightFailureMessage
 from anchorpy.error import extract_code_and_logs
-from ..program_id import MANGO_PROGRAM_ID
+from ..program_id import PROGRAM_ID
 from . import anchor
 from . import custom
 
@@ -23,7 +23,7 @@ def from_tx_error(
     error: RPCException,
 ) -> typing.Union[anchor.AnchorError, custom.CustomError, None]:
     err_info = error.args[0]
-    extracted = extract_code_and_logs(err_info, MANGO_PROGRAM_ID)
+    extracted = extract_code_and_logs(err_info, PROGRAM_ID)
     if extracted is None:
         return None
     return from_code(extracted[0])
