@@ -5,7 +5,7 @@ from spl.token.constants import TOKEN_PROGRAM_ID
 from solana.transaction import TransactionInstruction, AccountMeta
 import borsh_construct as borsh
 from .. import types
-from ..program_id import MANGO_PROGRAM_ID
+from ..program_id import PROGRAM_ID
 
 
 class FlashLoanEndArgs(typing.TypedDict):
@@ -23,7 +23,7 @@ class FlashLoanEndAccounts(typing.TypedDict):
 def flash_loan_end(
     args: FlashLoanEndArgs,
     accounts: FlashLoanEndAccounts,
-    program_id: PublicKey = MANGO_PROGRAM_ID,
+    program_id: PublicKey = PROGRAM_ID,
     remaining_accounts: typing.Optional[typing.List[AccountMeta]] = None,
 ) -> TransactionInstruction:
     keys: list[AccountMeta] = [
