@@ -4,7 +4,7 @@ from solana.publickey import PublicKey
 from solana.transaction import TransactionInstruction, AccountMeta
 import borsh_construct as borsh
 from .. import types
-from ..program_id import MANGO_PROGRAM_ID
+from ..program_id import PROGRAM_ID
 
 
 class StubOracleSetArgs(typing.TypedDict):
@@ -23,7 +23,7 @@ class StubOracleSetAccounts(typing.TypedDict):
 def stub_oracle_set(
     args: StubOracleSetArgs,
     accounts: StubOracleSetAccounts,
-    program_id: PublicKey = MANGO_PROGRAM_ID,
+    program_id: PublicKey = PROGRAM_ID,
     remaining_accounts: typing.Optional[typing.List[AccountMeta]] = None,
 ) -> TransactionInstruction:
     keys: list[AccountMeta] = [
