@@ -3,7 +3,8 @@ import typing
 from dataclasses import dataclass
 from construct import Container
 import borsh_construct as borsh
-from decimal import Decimal, getcontext
+import decimal
+import math
 
 
 class I80F48JSON(typing.TypedDict):
@@ -15,10 +16,6 @@ class I80F48:
     layout: typing.ClassVar = borsh.CStruct("val" / borsh.I128)
     val: int
 
-    MAX_SIZE = 128
-    FRACTIONS = 48
-    MULTIPLIER_BIG = 2 ** 48
-
     @classmethod
     def from_decoded(cls, obj: Container) -> "I80F48":
         return cls(val=obj.val)
@@ -33,5 +30,9 @@ class I80F48:
     def from_json(cls, obj: I80F48JSON) -> "I80F48":
         return cls(val=obj["val"])
 
-    def parsed(self):
-        return float(Decimal(self.val) / Decimal(self.MULTIPLIER_BIG))
+    def to_decimal(self) -> decimal.Decimal:
+        return decimal.Decimal(self.val) / decimal.Decimal(2 ** 48)
+
+    @classmethod
+    def from_decimal(cls, val: decimal.Decimal) -> "I80F48":
+        return cls(val=int(decimal.Decimal(val) * decimal.Decimal(2 ** 48)))
